/* This program will take WWIV gfile dirs, and convert them into PCB file
 * listings, which WWIV can then read in, descriptions are of course
 * truncated to fit in 59 columns.
 */


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "max_num.h"

typedef struct {
	char		name[41],		/* g-file section name */
			filename[9];		/* g-file database filename */
	unsigned char	sl,			/* sl required to read */
			age;			/* minimum age for section */
	unsigned short	maxfiles,		/* max # of files */
			ar;			/* AR for g-file section */
} gfiledirrec;

typedef struct {
	char		description[81],	/* description of file */
			filename[13];		/* filename of file */
	long		daten;			/* date added */
} gfilerec;

#define MAX_ENTRY 100
#define MAX_DIRS 64


void gfiles_menu(char path[])
/* Name       : gfiles_menu
 * Dependicies: needs a path to the data file, needs the return_valid
 *              procedure which is used in selection of the gfile dir.
 * Purpose    : Provides a simple menu interface to the directories.
 *              It also writes out the data file to the PCB format.
 * Revision   : ??? -=- Charles R. Grosvenor Jr. -=- Level 0
 *              February 22, 1994 -=- Charles R. Grosvenor Jr. -=- Level 1
 *                Touched up the comments a little, made it repeat until
 *                a 0 is entered.  Neatened up output so it can be distributed
 */

{
  gfiledirrec gdirs[MAX_DIRS+1];    /* current maximum is 64 */
  gfilerec gdescribe[MAX_ENTRY+1];  /* current maximum is 100 */
  FILE *infile, *outfile;
  int loop, loop2, count=1, count2, choice=1, total;
  size_t buffer;
  char temp[100], data_path[81];

    strcpy(data_path, path);
    strcat(data_path, "gfile.dat");
    if ( (infile=fopen(data_path, "rb")) == NULL)
    {
      printf("unable to find input, gfile.dat file!\n");
      exit(1);
    }
    while ((!feof(infile)) && (count<MAX_DIRS) ){
      buffer=fread(&gdirs[count-1], sizeof(gfiledirrec), 1, infile);
      if (buffer==1) count++;
    }
    count--;
    fclose(infile);
    while (choice>=0)
    {
      printf("\n\nPlease select the directory to use.\n\n");
      for (loop=1; loop<=count; loop++)
	printf("%-02d. %s\n",loop, gdirs[loop-1].name);
      printf("\nWhich Dir? : ");
      choice=return_valid(count)-1;
      if (choice>=0)
      {
	strcpy(temp, path);
	strcat(temp, gdirs[choice].filename);
	strcat(temp, ".GFL");

	if ( (infile=fopen(temp, "rb")) == NULL)
	{
	  printf("\n\nUnable to locate the data file: %s\n",temp);
	}
	else
	{
	  count2=1;
	  while ((!feof(infile)) && (count2<MAX_ENTRY)){
	    buffer=fread(&gdescribe[count2], sizeof(gfilerec), 1, infile);
	    if (buffer==1)
	    {
	      if (stricmp(gdescribe[count2].filename, " ")>0)
	      {  /* there's a space in there somewhere */
		 /* QBBS and PCBoard don't allow spaces in the filename */
		total=0;
		for (loop=0; loop<12; loop++)
		{
		  if (gdescribe[count2].filename[loop]!=' ')
		  {
		    gdescribe[count2].filename[total++]=gdescribe[count2].filename[loop];
		  }
		}
		for (;total<12; total++)
		{
		  gdescribe[count2].filename[total]=' ';
		}
	      }

	      count2++;
	    }
	  }
	  if ( (outfile=fopen(gdirs[choice].filename, "wb")) == NULL)
	  {
	    printf("Unable to create outputfile\n");
	  }
	  else
	  {
	    for (loop=1; loop<count2; loop++)
	    {
	      /* The 0's can be stripped out if a QBBS format is wanted  */
	      /* Checking for the file's existance and then getting size */
	      /* and date isn't too bad, but I didn't really need it for */
	      /* my purpose.  If you want it, add it yourself.           */
	      fprintf(outfile, "%s 00000000  00/00/00  %s\r\n", gdescribe[loop].filename,
				gdescribe[loop].description);
	    }
	    fclose(infile);
	  }
	  fclose(outfile);
	  printf("\n\nFile read and written out to %s%s.\n",path,gdirs[choice].filename);
	}
      }
    }
  printf("\n\n");
}


void main(int argc, char **argv)
{
  if (argc)
  {
    if (argv[1][strlen(argv[1])-1]!='\\')
    {
      strcat(argv[1], "\\");
    }
    gfiles_menu(argv[1]);
  }
  else
  {
    printf("Please enter the full path to your data directory.\n");
  }
}
